﻿/**
 * Copyright 2010 Canonical Ltd.
 * 
 * This file is part of UbuntuOne on Windows.
 * 
 * UbuntuOne on Windows is free software: you can redistribute it and/or modify		
 * it under the terms of the GNU Lesser General Public License version 		
 * as published by the Free Software Foundation.		
 *		
 * Ubuntu One on Windows is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
 * GNU Lesser General Public License for more details.	
 *
 * You should have received a copy of the GNU Lesser General Public License	
 * along with UbuntuOne for Windows.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Authors: Manuel de la Peña <manuel.delapena@canonical.com>
 */
using System;
using Canonical.UbuntuOne.Common;
using Canonical.UbuntuOne.Common.Validation;

namespace Canonical.UbuntuOne.Client
{
    class SyncDaemonClient : ISyncDaemonClient
    {
        /// <summary>
        /// Callback performed when a download starts.
        /// </summary>
        /// <param name="path">The path being downloaded.</param>
        /// <param name="data">The information of the download that is in process.</param>
        public void OnDownloadStarted(DownloadData data)
        {
            ValidateArgs.Begin()
                .IsNotNull(data, "data")
                .Check();

            throw new NotImplementedException();
        }

        /// <summary>
        /// Callback performed when a download finished. 
        /// </summary>
        /// <param name="path">The path of the download that was finished.</param>
        /// <param name="data">The information of the download that was finished.</param>
        public void OnDownloadFinished(DownloadData data)
        {
            ValidateArgs.Begin()
                .IsNotNull(data)
                .Check();

            throw new NotImplementedException();
        }

        /// <summary>
        /// Callback performed when an uploaded has been started.
        /// </summary>
        /// <param name="path">The path of the uploading file.</param>
        /// <param name="data">The information of the upload.</param>
        public void OnUploadStarted(UploadData data)
        {
            ValidateArgs.Begin()
                .IsNotNull(data)
                .Check();

            throw new NotImplementedException();
        }

        /// <summary>
        /// Calback performed when and upload has finished.
        /// </summary>
        /// <param name="path"></param>
        /// <param name="data"></param>
        public void OnUploadFinished(UploadData data)
        {
            ValidateArgs.Begin()
                .IsNotNull(data, "data")
                .Check();
            throw new NotImplementedException();
        }

        /// <summary>
        /// Callback performed when the status of the daemon has been changed.
        /// </summary>
        /// <param name="data">The information of the current state of the daemon.</param>
        public void OnStatusChanged(StateData data)
        {
            ValidateArgs.Begin()
                .IsNotNull(data, "data")
                .Check();
            throw new NotImplementedException();
        }

        /// <summary>
        /// Callback performed when the status of the account has changed.
        /// </summary>
        /// <param name="data">The data of the new account.</param>
        public void OnAccountChanged(AccountData data)
        {
            ValidateArgs.Begin()
                .IsNotNull(data, "data")
                .Check();
            throw new NotImplementedException();
        }

        /// <summary>
        /// Callback performed when a share has changed.
        /// </summary>
        /// <param name="data">The data of the sahred that changed.</param>
        public void OnShareChanged(ShareData data)
        {
            ValidateArgs.Begin()
                .IsNotNull(data, "data")
                .Check();
            throw new NotImplementedException();
        }

        /// <summary>
        /// Callback that well be called with the reponse when a share has been accepted.
        /// </summary>
        /// <param name="response">The reponse of the shared folder.</param>
        public void OnCreateShareResponse(ShareResponseData response)
        {
            ValidateArgs.Begin()
                .IsNotNull(response, "response")
                .Check();
            throw new NotImplementedException();
        }

        /// <summary>
        /// Callback called when a new share is created.
        /// </summary>
        /// <param name="data">The data of the new share.</param>
        public void OnNewShare(ShareData data)
        {
            ValidateArgs.Begin()
                .IsNotNull(data, "data")
                .Check();
            throw new NotImplementedException();
        }

        /// <summary>
        /// Callback that will be executed by the share service that will be performed when the 
        /// acceptation of a share was successful
        /// </summary>
        public void OnAcceptedShareSuccess()
        {
            throw new NotImplementedException();
        }

        /// <summary>
        /// Callback that will be executed by the share service that will be performed when there was an issue
        /// when accepting a share.
        /// </summary>
        public void OnAcceptedShareFailure()
        {
            throw new NotImplementedException();
        }

        /// <summary>
        /// Callback that will be executed by the share service that will be performed when there a share was rejected.
        /// </summary>
        public void OnRejectedShareSuccess()
        {
            throw new NotImplementedException();
        }

        /// <summary>
        /// Callback that will be executed by the share service when there was an error when rejecting a share.
        /// </summary>
        public void OnRejectedShareFailure()
        {
            throw new NotImplementedException();
        }

        /// <summary>
        /// Callback that will be executed by the share service when there was a new share created.
        /// </summary>
        public void OnCreateShareSuccess()
        {
            throw new NotImplementedException();
        }

        /// <summary>
        /// Callback that will be executed by the share service when there was an error when creating a share.
        /// </summary>
        public void OnCreateShareFailure()
        {
            throw new NotImplementedException();
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="data"></param>
        public void OnFolderCreateSuccess(UdfData data)
        {
            ValidateArgs.Begin()
                .IsNotNull(data, "data")
                .Check();
            throw new NotImplementedException();
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="data"></param>
        public void OnFolderCreateFailure(UdfData data)
        {
            ValidateArgs.Begin()
                .IsNotNull(data, "data")
                .Check();
            throw new NotImplementedException();
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="data"></param>
        public void OnFolderDeletedSuccess(UdfData data)
        {
            ValidateArgs.Begin()
                .IsNotNull(data, "data")
                .Check();
            throw new NotImplementedException();
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="data"></param>
        public void OnFolderDeletedError(UdfData data)
        {
            ValidateArgs.Begin()
                .IsNotNull(data, "data")
                .Check();
            throw new NotImplementedException();
        }
    }
}
