﻿/**
 * Copyright 2010 Canonical Ltd.
 * 
 * This file is part of UbuntuOne on Windows.
 * 
 * UbuntuOne on Windows is free software: you can redistribute it and/or modify		
 * it under the terms of the GNU Lesser General Public License version 		
 * as published by the Free Software Foundation.		
 *		
 * Ubuntu One on Windows is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
 * GNU Lesser General Public License for more details.	
 *
 * You should have received a copy of the GNU Lesser General Public License	
 * along with UbuntuOne for Windows.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Authors: Manuel de la Peña <manuel.delapena@canonical.com>
 */
using System;
using Canonical.UbuntuOne.Common.Aop;
using log4net;
using NUnit.Framework;
using Rhino.Mocks;
using Spring.Aop.Framework;

namespace Canonical.UbuntuOne.Common.Tests.Aop
{
    [TestFixture]
    public class DebugLogAfterThrowInterceptorFixture
    {
        #region Helpers classes

        public interface IDummy
        {
            string GetName();
        }

        public class Dummy : IDummy
        {
            public string GetName()
            {
                throw new NotImplementedException();
            }
        }

        #endregion

        #region Setup

        private MockRepository _mocks;
        private ILog _logger;
        private ProxyFactory _proxyFatory;
        private DebugLogAfterThrowInterceptor _interceptor;

        [SetUp]
        public void Setup()
        {
            _mocks = new MockRepository();
            _logger = _mocks.StrictMock<ILog>();
            _interceptor = new DebugLogAfterThrowInterceptor();
            _proxyFatory = new ProxyFactory(new Dummy());
            _proxyFatory.AddAdvice(_interceptor);
        }

        #endregion

        [Test]
        [ExpectedException(typeof(NotImplementedException))]
        public void AfterReturningPresentLoggerTest()
        {
            _interceptor.Logger = _logger;
            using (_mocks.Record())
            {
                // we expect the call of the logger
                Expect.Call(() => _logger.WarnFormat("{0} {1}", "", ""))
                    .IgnoreArguments()
                    .Repeat.Once();
            }
            using (_mocks.Playback())
            {
                var testClass = (IDummy)_proxyFatory.GetProxy();
                testClass.GetName();
            }
        }

        [Test]
        [ExpectedException(typeof(NotImplementedException))]
        public void AfterReturningNotPresentLoggerTest()
        {
            _interceptor.Logger = null;
            using (_mocks.Record())
            {
                Expect.Call(() => _logger.WarnFormat("{0} {1}", "", ""))
                    .IgnoreArguments()
                    .Repeat.Never();
            }
            using (_mocks.Playback())
            {
                var testClass = (IDummy)_proxyFatory.GetProxy();
                testClass.GetName();
            }
        }
    }
}
