﻿/**
 * Copyright 2010 Canonical Ltd.
 * 
 * This file is part of UbuntuOne on Windows.
 * 
 * UbuntuOne on Windows is free software: you can redistribute it and/or modify		
 * it under the terms of the GNU Lesser General Public License version 		
 * as published by the Free Software Foundation.		
 *		
 * Ubuntu One on Windows is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
 * GNU Lesser General Public License for more details.	
 *
 * You should have received a copy of the GNU Lesser General Public License	
 * along with UbuntuOne for Windows.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Authors: Manuel de la Peña <manuel.delapena@canonical.com>
 */

using System.Collections.Generic;
using Canonical.UbuntuOne.Common.Container;
using Rhino.Mocks;
using NUnit.Framework;

namespace Canonical.UbuntuOne.Common.Tests.Container
{
    [TestFixture]
    public class DictionaryContainerFixture
    {

        #region Variables

        private DictionaryContainer _container;
        private IContainer _iContainer;
        private MockRepository _mocks;

        #endregion

        #region SetUp

        [SetUp]
        public void Setup()
        {
            _mocks = new MockRepository();
            _iContainer = _mocks.StrictMock<IContainer>();
            _container = new DictionaryContainer();
        }

        #endregion

        #region Tests

        [Test]
        public void TestRegister()
        {
            // we test that the object is registered and that it can be retrieved.

            _container.Register(_iContainer);
            // we try to get the instance to make sure that it was added
            var instance = _container.GetImplementationOf<IContainer>();
            Assert.AreEqual(instance, _iContainer);

        }

        [Test]
        public void TestGetImplementationOf()
        {
            // try to get an un registered implementation
            try
            {
                _container.GetImplementationOf<IContainer>();
            }
            catch (KeyNotFoundException)
            {
                // expected
            }
            // register and get it
            _container.Register(_iContainer);
            try
            {
                var instance = _container.GetImplementationOf<IContainer>();
                Assert.AreEqual(instance, _iContainer);
            }
            catch (KeyNotFoundException e)
            {
                Assert.Fail("Exception {0} was not expected", e);
            }
        }

        [Test]
        public void TestClear()
        {
            // register data and later clear
            _container.Register(_iContainer);
            _container.Clear();
            try
            {
                _container.GetImplementationOf<IContainer>();
                Assert.Fail("Expected to have a KeyNotFoundException");
            }
            catch (KeyNotFoundException)
            {
                // expected
            }
        }
        #endregion

    }
}
