﻿/**
 * Copyright 2010 Canonical Ltd.
 * 
 * This file is part of UbuntuOne on Windows.
 * 
 * UbuntuOne on Windows is free software: you can redistribute it and/or modify		
 * it under the terms of the GNU Lesser General Public License version 		
 * as published by the Free Software Foundation.		
 *		
 * Ubuntu One on Windows is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
 * GNU Lesser General Public License for more details.	
 *
 * You should have received a copy of the GNU Lesser General Public License	
 * along with UbuntuOne for Windows.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Authors: Manuel de la Peña <manuel.delapena@canonical.com>
 */

using System;
using Canonical.UbuntuOne.Common.Container;
using NUnit.Framework;
using Rhino.Mocks;

namespace Canonical.UbuntuOne.Common.Tests.Container
{
    [TestFixture]
    public class ObjectsContainerFixture
    {

        #region Variables

        private MockRepository _mocks;
        private IContainer _container;

        #endregion

        #region SetUp

        [SetUp]
        public void Setup()
        {
            _mocks = new MockRepository();
            _container = _mocks.StrictMock<IContainer>();
            ObjectsContainer.Initialize(_container);
        }

        #endregion

        #region Tests

        [Test]
        public void ClearSuccesTest()
        {
            using (_mocks.Record())
            {
                // expect the call the the void method clear
                Expect.Call(() => _container.Clear());
            }
            using (_mocks.Playback())
            {
                ObjectsContainer.Clear();
            }
        }

        [Test]
        [ExpectedException(typeof(InvalidOperationException))]
        public void GetMapperNoContainerTest()
        {
            // try the metho when no container has been given
            ObjectsContainer.Clear();

            ObjectsContainer.GetMapper<String, Type>();
            Assert.Fail("Expected InvalidOperationException");

        }

        [Test]
        [ExpectedException(typeof(UnsatisfiedDependencyException))]
        public void GetMapperNoMapperTest()
        {

            ObjectsContainer.Clear();
            _container.Clear();
            ObjectsContainer.Initialize(_container);
            using (_mocks.Record())
            {
                Expect.Call(_container.GetImplementationOf<IMapper<String, Type>>())
                    .Throw(new UnsatisfiedDependencyException("Test exception"));
            }
            using (_mocks.Playback())
            {
                ObjectsContainer.GetMapper<String, Type>();
            }
        }

        [Test]
        [ExpectedException(typeof(InvalidOperationException))]
        public void RegisterNoContainerTest()
        {
            // try the metho when no container has been given
            ObjectsContainer.Clear();
            ObjectsContainer.Register(_container);

        }

        [Test]
        public void RegisterTest()
        {
            Expect.Call(() => _container.Register(_container));
            ObjectsContainer.Register(_container);

        }

        [Test]
        public void GetImplementationOfTest()
        {
            // register the implementation of something and try to retrieve it
            ObjectsContainer.Register(_container);
            using (_mocks.Record())
            {
                Expect.Call(_container.GetImplementationOf<IContainer>()).Return(_container);
            }
            var implementation = ObjectsContainer.GetImplementationOf<IContainer>();
            // we ensure that the container is the correct one
            Assert.AreEqual(implementation, _container);

        }


        [Test]
        [ExpectedException(typeof(InvalidOperationException))]
        public void ClearFailTest()
        {
            // clear the container and expect an invalid operation exceiotn.
            ObjectsContainer.Clear();
            ObjectsContainer.Register(_container);
        }

        #endregion

    }
}
