﻿/**
 * Copyright 2010 Canonical Ltd.
 * 
 * This file is part of UbuntuOne on Windows.
 * 
 * UbuntuOne on Windows is free software: you can redistribute it and/or modify		
 * it under the terms of the GNU Lesser General Public License version 		
 * as published by the Free Software Foundation.		
 *		
 * Ubuntu One on Windows is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
 * GNU Lesser General Public License for more details.	
 *
 * You should have received a copy of the GNU Lesser General Public License	
 * along with UbuntuOne for Windows.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Authors: Manuel de la Peña <manuel.delapena@canonical.com>
 */
using System;
using Canonical.UbuntuOne.Common.Validation;
using NUnit.Framework;

namespace Canonical.UbuntuOne.Common.Tests.Validation
{
    [TestFixture]
    public class ValidationExtensionsFixture
    {

        #region Tests

        [Test]
        public void IsNotNullTrueTest()
        {
            ValidateArgs.Begin()
                .IsNotNull("not null")
                .Check();
        }

        [Test]
        [ExpectedException(typeof(ValidationException))]
        public void IsNotNullFalseTest()
        {
            string nullString = null;
            ValidateArgs.Begin()
                .IsNotNull(nullString)
                .Check();
        }

        [Test]
        [ExpectedException(typeof(ValidationException))]
        public void IsTrueFailTest()
        {
            ValidateArgs.Begin()
                .IsTrue(false, "Should be true.")
                .Check();
        }

        [Test]
        public void IsTrueCorrectTest()
        {
            ValidateArgs.Begin()
                .IsTrue(true, "Should be true")
                .Check();
        }


        [Test]
        public void IsPositiveTrueTest()
        {
            ValidateArgs.Begin()
                .IsPositive(3, "Is positive")
                .Check();
        }

        [Test]
        [ExpectedException(typeof(ValidationException))]
        public void IsPositiveFalseTest()
        {
            ValidateArgs.Begin()
                .IsPositive(-1, "Is positive")
                .Check();
        }

        [Test]
        public void IsOfTypeTrueTest()
        {
            ValidateArgs.Begin()
                .IsOfType("string", typeof (String), "Should be string")
                .Check();
        }

        [Test]
        [ExpectedException(typeof(ValidationException))]
        public void IsOfTypeFalseTest()
        {
            ValidateArgs.Begin()
                .IsOfType("string", typeof (ValidationException), "should be exception")
                .Check();
        }

        [Test]
        public void IsUtcDateTrueTest()
        {
            ValidateArgs.Begin()
                .IsUtcDateTime(DateTime.Now.ToUniversalTime(), "Should be utc")
                .Check();
        }

        [Test]
        [ExpectedException(typeof(ValidationException))]
        public void IsUtcDateFalseTest()
        {
            ValidateArgs.Begin()
                .IsUtcDateTime(DateTime.Now, "Should be utc")
                .Check();
        }

        #endregion

    }
}
