﻿/**
 * Copyright 2010 Canonical Ltd.
 * 
 * This file is part of UbuntuOne on Windows.
 * 
 * UbuntuOne on Windows is free software: you can redistribute it and/or modify		
 * it under the terms of the GNU Lesser General Public License version 		
 * as published by the Free Software Foundation.		
 *		
 * Ubuntu One on Windows is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
 * GNU Lesser General Public License for more details.	
 *
 * You should have received a copy of the GNU Lesser General Public License	
 * along with UbuntuOne for Windows.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Authors: Manuel de la Peña <manuel.delapena@canonical.com>
 */
using System;
using System.Reflection;
using System.Text;
using log4net;

namespace Canonical.UbuntuOne.Common.Aop
{
    /// <summary>
    /// Abstract class to be extended by all those interceptors that add extra logging to 
    /// a method call.
    /// </summary>
    public abstract class LoggingInterceptor
    {
        #region DI properties

        /// <summary>
        /// Allows to inject the logger that will be used to log about a method invocation.
        /// </summary>
        public ILog Logger { get; set; }

        #endregion

        /// <summary>
        /// Allows to log a call of a method that has no arguments.
        /// </summary>
        /// <param name="method">The method that is being called.</param>
        /// <returns>The log message to be used.</returns>
        protected static string LogNoArguments(MethodInfo method)
        {
            return String.Format("{0}()", method.Name);
        }

        /// <summary>
        /// Allows to log a call of a method that as a collection of arguments.
        /// </summary>
        /// <param name="method">The method that is being called.</param>
        /// <param name="args">The arguments which were used to call the method.</param>
        /// <returns>The log message to be used.</returns>
        protected static string LogArguments(MethodInfo method, object[] args)
        {
            var sb = new StringBuilder(String.Format("{0}(", method.Name));
            foreach (var argument in args)
            {
                sb.Append(argument);
                sb.Append(", ");
            }
            var result = sb.ToString();
            result = result.Remove(result.LastIndexOf(','));
            return result + ")";
        }
    }
}
