﻿/**
 * Copyright 2010 Canonical Ltd.
 * 
 * This file is part of UbuntuOne on Windows.
 * 
 * UbuntuOne on Windows is free software: you can redistribute it and/or modify		
 * it under the terms of the GNU Lesser General Public License version 		
 * as published by the Free Software Foundation.		
 *		
 * Ubuntu One on Windows is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
 * GNU Lesser General Public License for more details.	
 *
 * You should have received a copy of the GNU Lesser General Public License	
 * along with UbuntuOne for Windows.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Authors: Manuel de la Peña <manuel.delapena@canonical.com>
 */
using System;
using System.Collections.Generic;
using log4net;

namespace Canonical.UbuntuOne.Common.Container
{
    public class DictionaryContainer : IContainer
    {
        #region Private variables

        private static readonly ILog _logger = LogManager.GetLogger(typeof(DictionaryContainer));
        private readonly Dictionary<Type, object> _types = new Dictionary<Type, object>();

        #endregion

        #region IContainer implementation

        /// <summary>
        /// Registers the specified implementation for a type.
        /// </summary>
        /// <typeparam name="T">Type to register an implementation for.</typeparam>
        /// <param name="implementationToRegister">The implementation to register.</param>
        public void Register<T>(T implementationToRegister)
        {
            _types.Add(typeof(T), implementationToRegister);
        }

        /// <summary>
        /// Gets the implementation of a type.
        /// </summary>
        /// <typeparam name="T">Type to retrieve</typeparam>
        /// <returns>Implementation of a type</returns>
        public T GetImplementationOf<T>() where T : class
        {
            var result = (T)_types[typeof(T)];
            return result;
        }

        public void Clear()
        {
            _types.Clear();
        }

        #endregion
    }
}
