﻿/**
 * Copyright 2010 Canonical Ltd.
 * 
 * This file is part of UbuntuOne on Windows.
 * 
 * UbuntuOne on Windows is free software: you can redistribute it and/or modify		
 * it under the terms of the GNU Lesser General Public License version 		
 * as published by the Free Software Foundation.		
 *		
 * Ubuntu One on Windows is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
 * GNU Lesser General Public License for more details.	
 *
 * You should have received a copy of the GNU Lesser General Public License	
 * along with UbuntuOne for Windows.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Authors: Manuel de la Peña <manuel.delapena@canonical.com>
 */
namespace Canonical.UbuntuOne.Common
{
    public interface IProcessManager
    {
        /// <summary>
        /// Implementators of this method should start the process and throw an exception if it was not possible.
        /// </summary>
        /// <exception cref="ProcessManagementException">This exception is thrown when the process could not be started.</exception>
        void Start();

        /// <summary>
        /// Implementators of this method should start a process and return a boolean value stating if
        /// the process was correctly started. Using this method allows to avoid the need to catch an dexception.
        /// </summary>
        /// <returns>Booelan flag stating if the process was indeed started.</returns>
        bool TryStart();

        /// <summary>
        /// Implementators of this method should stop a process that has been currently running.
        /// </summary>
        /// <exception cref="ProcessManagementException">This exception is thrown when the process has not yet been started.</exception>
        void Stop();

        /// <summary>
        /// Implementators of this method should ensure that the process can be stopped, if it cannot be stopped they should
        /// return a boolean flag rather than raising an exception.
        /// </summary>
        /// <returns></returns>
        bool TryStop();

        /// <summary>
        /// Returns if the process has already been started.
        /// </summary>
        bool IsRunning { get; }

    }
}
