﻿/**
 * Copyright 2010 Canonical Ltd.
 * 
 * This file is part of UbuntuOne on Windows.
 * 
 * UbuntuOne on Windows is free software: you can redistribute it and/or modify		
 * it under the terms of the GNU Lesser General Public License version 		
 * as published by the Free Software Foundation.		
 *		
 * Ubuntu One on Windows is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
 * GNU Lesser General Public License for more details.	
 *
 * You should have received a copy of the GNU Lesser General Public License	
 * along with UbuntuOne for Windows.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Authors: Manuel de la Peña <manuel.delapena@canonical.com>
 */
using System.ServiceModel;

namespace Canonical.UbuntuOne.Common
{
    [ServiceContract(
        Name = "SyncConfiguration",
        Namespace = "http://one.ubuntu.com/syncconfiguration",
        CallbackContract = typeof(ISyncDaemonClient),
        SessionMode = SessionMode.Required)]
    public interface ISyncConfiguration
    {
        /// <summary>
        /// Returns the throttling limits that have been set up for the daemon.
        /// </summary>
        /// <returns>The upload and downloads limits that the daemon has.</returns>
        [OperationContract]
        ThrottlingData GetThrottlingLimits();

        /// <summary>
        /// Allows to set the upload and download limits that the daemon must have.
        /// </summary>
        /// <param name="limits">The upload and download limits.</param>
        [OperationContract]
        void SetThrottlingLimits(ThrottlingData limits);

        /// <summary>
        /// Allows to set the throttling limits feature.
        /// </summary>
        /// <param name="isEnabled">A bool indicating if it should be enabled or not.</param>
        [OperationContract]
        void EnableThrottlingLimits(bool isEnabled);

        /// <summary>
        /// Allows to retrieve if the thottling limits ahve been enabled.
        /// </summary>
        /// <returns>A boolean telling if the limits are enabled.</returns>
        [OperationContract]
        bool IsEnabledThrottlingLimits();

        /// <summary>
        /// Allows to enable the auto subscrive to udfs.
        /// </summary>
        /// <param name="isEnable">A bool indicating if the preferrence should be enabled.</param>
        [OperationContract]
        void EnableUdfAutosubscribe(bool isEnable);

        /// <summary>
        /// Returns if the Autosubscrive preference has been enabled.
        /// </summary>
        /// <returns>A bool indicating if the autosibscribe options is on.</returns>
        [OperationContract]
        bool IsEnabledUdfAutosubscribe();
    }
}
