﻿/**
 * Copyright 2010 Canonical Ltd.
 * 
 * This file is part of UbuntuOne on Windows.
 * 
 * UbuntuOne on Windows is free software: you can redistribute it and/or modify		
 * it under the terms of the GNU Lesser General Public License version 		
 * as published by the Free Software Foundation.		
 *		
 * Ubuntu One on Windows is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
 * GNU Lesser General Public License for more details.	
 *
 * You should have received a copy of the GNU Lesser General Public License	
 * along with UbuntuOne for Windows.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Authors: Manuel de la Peña <manuel.delapena@canonical.com>
 */
using System.Collections.Generic;
using System.ServiceModel;

namespace Canonical.UbuntuOne.Common
{
	/// <summary>
	/// The implementators of this interface should allow the callng clients to perform a number of applications on 
	/// the sync daemon from windows. This will allow users to interact with the daemon through .Net.
	/// </summary>
    [ServiceContract(
        Name = "SyncDaemon",
        Namespace = "http://one.ubuntu.com/syncdaemon",
        CallbackContract = typeof(ISyncDaemonClient),
        SessionMode = SessionMode.Required)]
	public interface ISyncDaemon
	{
		/// <summary>
		/// Allows to start the daemon by a client.
		/// </summary>
		[OperationContract]
		void Start();
		
		/// <summary>
		/// Allows to try and start a daemon from the client. If the daemon cannot be started a false will be returned.
		/// </summary>
		/// <returns>A boolean flag telling if the daemon could be started.</returns>
		[OperationContract]
		bool TryStart();
		
		/// <summary>
		/// Allows to stop the daemon by a client.
		/// </summary>
		[OperationContract]
		void Stop();
		
		/// <summary>
		/// Allows to try and stop the daemon from the client. If the daemon cannot be stopped a false will be returned.
		/// </summary>
		/// <returns>A boolean flag telling if the daemong could bs stopped.</returns>
		[OperationContract]
		bool TryStop();

        /// <summary>
        /// Allows to query the service about the current status of the daemon.
        /// </summary>
        /// <returns>A data contract that contains the current status of the daemon.</returns>
        [OperationContract]
	    StateData GetCurrentStatus();

        /// <summary>
        /// Allows to query the service to return the downloads that are currently being performed.
        /// </summary>
        /// <returns>A list with all the current downloads being processed by the daemon.</returns>
	    [OperationContract]
	    IList<DownloadData> GetCurrentDownloads();

        /// <summary>
        /// Allows to query the service to return the items that are either waiting from upload or download.
        /// </summary>
        /// <returns>The list of items that are in the queue to be processed.</returns>
        [OperationContract]
	    IList<QueueItemData> GetWaitingContent();

        /// <summary>
        /// Allows the client to schedule the share and node be next in the
        // queue of waiting commands.
        /// </summary>
        /// <param name="shareId">The unique id that describes the share.</param>
        /// <param name="nodeId">The unique id that describes the node.</param>
	    [OperationContract]
	    void ScheduleAsNext(string shareId, string nodeId);

        /// <summary>
        /// Allows to query the aemon to retrieve all the different nodes that are currently neing uploaded.
        /// </summary>
        /// <returns>The list of the objects currently being uploaded.</returns>
	    [OperationContract]
	    IList<UploadData> GetCurrentUploads();

        /// <summary>
        /// Allows the client to tell the daemon to connect. The daemon should not connect automatically, this
        /// should be explicitly stated by the client.
        /// </summary>
	    [OperationContract]
	    void Connect();

        /// <summary>
        /// Allows the client to tell the daemon to disconnect.
        /// </summary>
        [OperationContract]
	    void Disconnect();

        /// <summary>
        /// Allows the client to query the root directoy used by the daemon.
        /// </summary>
        /// <returns></returns>
	    [OperationContract]
	    string GetRootDirectory();

        /// <summary>
        /// Allows client to tell the sync daemon to quit. Discomment allows the daemon toquee the event
        /// for the next time it connects, quit completelly closes the service and stops listening the IO changes.
        /// </summary>
	    [OperationContract]
	    void Quit();
	}
}
