﻿/**
 * Copyright 2010 Canonical Ltd.
 * 
 * This file is part of UbuntuOne on Windows.
 * 
 * UbuntuOne on Windows is free software: you can redistribute it and/or modify		
 * it under the terms of the GNU Lesser General Public License version 		
 * as published by the Free Software Foundation.		
 *		
 * Ubuntu One on Windows is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
 * GNU Lesser General Public License for more details.	
 *
 * You should have received a copy of the GNU Lesser General Public License	
 * along with UbuntuOne for Windows.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Authors: Manuel de la Peña <manuel.delapena@canonical.com>
 */
using System.ServiceModel;

namespace Canonical.UbuntuOne.Common
{
    [ServiceContract(Namespace = "http://one.ubuntu.com/client")]
    public interface ISyncDaemonClient
    {
        /// <summary>
        /// Callback performed when a download starts.
        /// </summary>
        /// <param name="path">The path being downloaded.</param>
        /// <param name="data">The information of the download that is in process.</param>
        [OperationContract(IsOneWay = true)]
        void OnDownloadStarted(DownloadData data);

        /// <summary>
        /// Callback performed when a download finished. 
        /// </summary>
        /// <param name="path">The path of the download that was finished.</param>
        /// <param name="data">The information of the download that was finished.</param>
        [OperationContract(IsOneWay = true)]
        void OnDownloadFinished(DownloadData data);

        /// <summary>
        /// Callback performed when an uploaded has been started.
        /// </summary>
        /// <param name="path">The path of the uploading file.</param>
        /// <param name="data">The information of the upload.</param>
        [OperationContract(IsOneWay = true)]
        void OnUploadStarted(UploadData data);

        /// <summary>
        /// Calback performed when and upload has finished.
        /// </summary>
        /// <param name="path">The path whose upload has finished.</param>
        /// <param name="data">The data of the upload.</param>
        [OperationContract(IsOneWay = true)]
        void OnUploadFinished(UploadData data);

        /// <summary>
        /// Callback performed when the status of the daemon has been changed.
        /// </summary>
        /// <param name="data">The information of the current state of the daemon.</param>
        [OperationContract(IsOneWay = true)]
        void OnStatusChanged(StateData data);

        /// <summary>
        /// Callback performed when the status of the account has changed.
        /// </summary>
        /// <param name="data">The data of the new account.</param>
        [OperationContract(IsOneWay = true)]
        void OnAccountChanged(AccountData data);

        /// <summary>
        /// Callback performed when a share has changed.
        /// </summary>
        /// <param name="data">The data of the sahred that changed.</param>
        [OperationContract(IsOneWay = true)]
        void OnShareChanged(ShareData data);

        /// <summary>
        /// Callback that well be called with the reponse when a share has been accepted.
        /// </summary>
        /// <param name="response">The reponse of the shared folder.</param>
        [OperationContract(IsOneWay = true)]
        void OnCreateShareResponse(ShareResponseData response);

        /// <summary>
        /// Callback called when a new share is created.
        /// </summary>
        /// <param name="data">The data of the new share.</param>
        [OperationContract(IsOneWay = true)]
        void OnNewShare(ShareData data);

        /// <summary>
        /// Callback that will be executed by the share service that will be performed when the 
        /// acceptation of a share was successful
        /// </summary>
        [OperationContract(IsOneWay = true)]
        void OnAcceptedShareSuccess();

        /// <summary>
        /// Callback that will be executed by the share service that will be performed when there was an issue
        /// when accepting a share.
        /// </summary>
        [OperationContract(IsOneWay = true)]
        void OnAcceptedShareFailure();

        /// <summary>
        /// Callback that will be executed by the share service that will be performed when there a share was rejected.
        /// </summary>
        [OperationContract(IsOneWay = true)]
        void OnRejectedShareSuccess();

        /// <summary>
        /// Callback that will be executed by the share service when there was an error when rejecting a share.
        /// </summary>
        [OperationContract(IsOneWay = true)]
        void OnRejectedShareFailure();

        /// <summary>
        /// Callback that will be executed by the share service when there was a new share created.
        /// </summary>
        [OperationContract(IsOneWay = true)]
        void OnCreateShareSuccess();

        /// <summary>
        /// Callback that will be executed by the share service when there was an error when creating a share.
        /// </summary>
        [OperationContract(IsOneWay = true)]
        void OnCreateShareFailure();

        /// <summary>
        /// Callabck that will be executed when the creation of a new folder was succesful.
        /// </summary>
        /// <param name="data">The data of the new created udf.</param>
        [OperationContract(IsOneWay = true)]
        void OnFolderCreateSuccess(UdfData data);

        /// <summary>
        /// Callback that will be executed when the creation of a new folder could not be performed.
        /// </summary>
        /// <param name="data">The data of the udf we tried to created.</param>
        [OperationContract(IsOneWay = true)]
        void OnFolderCreateFailure(UdfData data);

        /// <summary>
        /// Callback that will be executed when the deletion of a folder was successful.
        /// </summary>
        /// <param name="data">The data of the deleted udf.</param>
        [OperationContract(IsOneWay = true)]
        void OnFolderDeletedSuccess(UdfData data);

        /// <summary>
        /// Callback that wil be executed when the deletion of a folder did not succed.
        /// </summary>
        /// <param name="data">The data of the udf we tried to delete.</param>
        [OperationContract(IsOneWay = true)]
        void OnFolderDeletedError(UdfData data);
    }
}
