﻿/**
 * Copyright 2010 Canonical Ltd.
 * 
 * This file is part of UbuntuOne on Windows.
 * 
 * UbuntuOne on Windows is free software: you can redistribute it and/or modify		
 * it under the terms of the GNU Lesser General Public License version 		
 * as published by the Free Software Foundation.		
 *		
 * Ubuntu One on Windows is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
 * GNU Lesser General Public License for more details.	
 *
 * You should have received a copy of the GNU Lesser General Public License	
 * along with UbuntuOne for Windows.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Authors: Manuel de la Peña <manuel.delapena@canonical.com>
 */
using System.Collections.Generic;
using System.ServiceModel;

namespace Canonical.UbuntuOne.Common
{
    [ServiceContract(
        Name = "SyncFolders",
        Namespace = "http://one.ubuntu.com/syncfolders",
        CallbackContract = typeof(ISyncDaemonClient),
        SessionMode = SessionMode.Required)]
    public interface ISyncFolders
    {
        /// <summary>
        /// Creates a new udf for the given path.
        /// </summary>
        /// <param name="path">The path to which the Udf will be created.</param>
        [OperationContract(IsOneWay = true)]
        void CreateFolderUdf(string path);

        /// <summary>
        /// Deletes the udf go the given path.
        /// </summary>
        /// <param name="path">The path whose Udf we will remove.</param>
        [OperationContract(IsOneWay = true)]
        void DeleteFolderUdf(string path);

        /// <summary>
        /// Returns a list of all the udfs.
        /// </summary>
        /// <returns>A list with all the udfs.</returns>
        [OperationContract]
        IList<UdfData> GetFolders();

        /// <summary>
        /// Allows the client to tell the sync daemon to subscribe to a folder id.
        /// </summary>
        /// <param name="folderId">The id of the folder to subscribe to.</param>
        [OperationContract]
        void Subscribe(string folderId);

        /// <summary>
        /// Allows the client to tell the daemon to unsubscribe from the given folder id.
        /// </summary>
        /// <param name="folderId">The id of the folder to unsubscribe from.</param>
        [OperationContract]
        void Unsubscribe(string folderId);

        /// <summary>
        /// Allows the client to request the Udf data for a given path.
        /// </summary>
        /// <param name="path">The path whose udf we want to get.</param>
        /// <returns>The udf data of the given path.</returns>
        [OperationContract]
        UdfData GetInfo(string path);

        /// <summary>
        /// Refreshes the states of the volumns.
        /// </summary>
        [OperationContract]
        void RefreshVolumes();

    }
}
