﻿/**
 * Copyright 2010 Canonical Ltd.
 * 
 * This file is part of UbuntuOne on Windows.
 * 
 * UbuntuOne on Windows is free software: you can redistribute it and/or modify		
 * it under the terms of the GNU Lesser General Public License version 		
 * as published by the Free Software Foundation.		
 *		
 * Ubuntu One on Windows is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
 * GNU Lesser General Public License for more details.	
 *
 * You should have received a copy of the GNU Lesser General Public License	
 * along with UbuntuOne for Windows.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Authors: Manuel de la Peña <manuel.delapena@canonical.com>
 */
using System.Collections.Generic;
using System.ServiceModel;

namespace Canonical.UbuntuOne.Common
{
    [ServiceContract(
        Name = "SyncShares",
        Namespace = "http://one.ubuntu.com/shares",
        CallbackContract = typeof(ISyncDaemonClient),
        SessionMode = SessionMode.Required)]
    public interface ISyncShares
    {
        /// <summary>
        /// Allows the client to query and get all the different shares that the user has.
        /// </summary>
        /// <returns>Returns a list with all the shares that the user has.</returns>
        [OperationContract]
        IList<ShareData> GetShares();

        /// <summary>
        /// Allows the client to accept the share. The implementator should call the OnAcceptedShareSuccess or 
        /// OnAcceptedShareFailure callbacks from the client appropietly.
        /// </summary>
        /// <param name="shareId">The id of the share to accept.</param>
        [OperationContract(IsOneWay = true)]
        void AcceptShare(string shareId);

        /// <summary>
        /// Allows the client to reject a share. The implentator should call the OnRejectShareSuccess or
        /// OnRejectShareFailure callbacks from the client.
        /// </summary>
        /// <param name="shareId">The id of the share to reject.</param>
        [OperationContract(IsOneWay = true)]
        void RejectShare(string shareId);

        /// <summary>
        /// Allows the client to create a new share. The implementator should call the OnCreateShareSuccess or
        /// OnCreateShareFailure callbacks from the client.
        /// </summary>
        /// <param name="path">The path to be shared.</param>
        /// <param name="username">The username to share the path with.</param>
        /// <param name="name">The name of the share.</param>
        /// <param name="accessLevel">The access level that the user we share with can have in the share.</param>
        [OperationContract(IsOneWay = true)]
        void CreateShare(string path, string username, string name, AccessLevel accessLevel);

        /// <summary>
        /// Allows the client to poke the daemon to refresh the shares.
        /// </summary>
        [OperationContract]
        void UpdateShares();

        /// <summary>
        /// Allows the client to query which shars exist.
        /// </summary>
        /// <returns>A list with the current shares.</returns>
        [OperationContract]
        IList<ShareData> GetShared();
    }
}
