﻿/**
 * Copyright 2010 Canonical Ltd.
 * 
 * This file is part of UbuntuOne on Windows.
 * 
 * UbuntuOne on Windows is free software: you can redistribute it and/or modify		
 * it under the terms of the GNU Lesser General Public License version 		
 * as published by the Free Software Foundation.		
 *		
 * Ubuntu One on Windows is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
 * GNU Lesser General Public License for more details.	
 *
 * You should have received a copy of the GNU Lesser General Public License	
 * along with UbuntuOne for Windows.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Authors: Manuel de la Peña <manuel.delapena@canonical.com>
 */
using System;
using Microsoft.ApplicationBlocks.Updater;

namespace Canonical.UbuntuOne.Common.Update
{
    /// <summary>
    /// Internal interface that is used as a wrapper for the DotUpdater so that it can be
    /// mock in the unit tests.
    /// </summary>
    internal interface IDotUpdaterWrapper : IDisposable
    {
        /// <summary>
        /// Event that is reaised when the download of an update has been completed.
        /// </summary>
        event EventHandler<TaskEventArgs> OnDownloadCompleted;

        /// <summary>
        /// Event that is raised when there has been progress when downloading the update.
        /// </summary>
        event EventHandler<DownloadTaskProgressEventArgs> OnDownloadProgress;

        /// <summary>
        /// Event that is raised when there has been an error with the download.
        /// </summary>
        event EventHandler<DownloadTaskErrorEventArgs> OnDownloadError;

        /// <summary>
        /// Method that will connect to the server and will return a UpdaterTask if there is a possible
        /// update, if there are no updates available a null pointer will be returned.
        /// </summary>
        /// <returns>A null pointer if no updates are available or an update taks if there are.</returns>
        UpdaterTask CheckForUpdates();

        /// <summary>
        /// Method that will install the given update.
        /// </summary>
        /// <param name="task">The taks that will be used to udpate.</param>
        void Install(UpdaterTask task);

        /// <summary>
        /// Method that will being the download of a given update task.
        /// </summary>
        /// <param name="task">The taks that will have to be downloaded.</param>
        void BeginDownload(UpdaterTask task);
    }
}
