﻿/**
 * Copyright 2010 Canonical Ltd.
 * 
 * This file is part of UbuntuOne on Windows.
 * 
 * UbuntuOne on Windows is free software: you can redistribute it and/or modify		
 * it under the terms of the GNU Lesser General Public License version 		
 * as published by the Free Software Foundation.		
 *		
 * Ubuntu One on Windows is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
 * GNU Lesser General Public License for more details.	
 *
 * You should have received a copy of the GNU Lesser General Public License	
 * along with UbuntuOne for Windows.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Authors: Manuel de la Peña <manuel.delapena@canonical.com>
 */
using Microsoft.ApplicationBlocks.Updater;

namespace Canonical.UbuntuOne.Common.Update
{
    /// <summary>
    /// Interface that represents the view that will ask for a confirmation to the user
    /// regarding the update procedure.
    /// </summary>
    public interface IUpdateView
    {
        /// <summary>
        /// This method should prompt some kind of confirmation message to the user
        /// and return if he decided to update the application or not.
        /// </summary>
        /// <returns>The answer that the user provided.</returns>
        UpdateConfirmation AskForDownloadConfirmation();

        /// <summary>
        /// This method should prompt some kind of confirmation to the user to close and install the update
        /// of the application.
        /// </summary>
        /// <returns>The answer that the suer provided.</returns>
        UpdateConfirmation AskForCloseAnInstallConfirmation();

        /// <summary>
        /// This method wil be called when the update finished. The view should show the appropiate
        /// data to the user when this occurs.
        /// </summary>
        void Updatefinished();

        /// <summary>
        /// Handler that will be used when there is an update in the progress of the download.
        /// This handler can be used to allow the user know the progress of the download.
        /// </summary>
        /// <param name="sender">The object that sent the arguments.</param>
        /// <param name="args">The event arguments that provide the information to be 
        /// shown to the user.</param>
        void DownloadProgressHandler(object sender, DownloadTaskProgressEventArgs args);

        /// <summary>
        /// Handler that will be used when there was an error in the update. This will allow
        /// the view to communicate the user that there was an error but should not try to do anything about 
        /// it since this object is just a view.
        /// </summary>
        /// <param name="sender">The object that sent the event.</param>
        /// <param name="args">The event arguments that provide the information to be 
        /// shown to the user.</param>
        void DownloadErrorHandler(object sender, DownloadTaskErrorEventArgs args);

        /// <summary>
        /// Handler that will be used when the download of the updates finished. This will allows th view
        /// to let the user know that we finished and that the updating will be in progress.
        /// </summary>
        /// <param name="sender">The object that sent the event.</param>
        /// <param name="e">The event arguments that provide the information to be 
        /// shown to the user.</param>
        void DownloadUpdateCompleted(object sender, TaskEventArgs e);
    }
}
