﻿/**
 * Copyright 2010 Canonical Ltd.
 * 
 * This file is part of UbuntuOne on Windows.
 * 
 * UbuntuOne on Windows is free software: you can redistribute it and/or modify		
 * it under the terms of the GNU Lesser General Public License version 		
 * as published by the Free Software Foundation.		
 *		
 * Ubuntu One on Windows is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
 * GNU Lesser General Public License for more details.	
 *
 * You should have received a copy of the GNU Lesser General Public License	
 * along with UbuntuOne for Windows.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Authors: Manuel de la Peña <manuel.delapena@canonical.com>
 */

using System;

namespace Canonical.UbuntuOne.Common.Update
{
    /// <summary>
    /// This interface must be implemented by those classes that will provide the avility of
    /// updating the application.
    /// </summary>
    public interface IUpdater : IDisposable
    {

        /// <summary>
        /// Gets and sets the feed that will be used to check for updates.
        /// </summary>
        string RSSFeed { get; set; }

        /// <summary>
        /// Gets and sets the view that will be used to ask for confirmation when an update exists.
        /// </summary>
        IUpdateView UpdateView { get; set; }

        /// <summary>
        /// Returns if the are updates present for the application.
        /// </summary>
        /// <returns>A flag indicating if updates are available.</returns>
        bool UpdatesArePresent();

        /// <summary>
        /// This method will perform the update of the application using a msi installer that
        /// is fecthed from the rss feed.
        /// </summary>
        void PerformUpdate();

    }
}
