﻿/**
 * Copyright 2010 Canonical Ltd.
 * 
 * This file is part of UbuntuOne on Windows.
 * 
 * UbuntuOne on Windows is free software: you can redistribute it and/or modify		
 * it under the terms of the GNU Lesser General Public License version 		
 * as published by the Free Software Foundation.		
 *		
 * Ubuntu One on Windows is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
 * GNU Lesser General Public License for more details.	
 *
 * You should have received a copy of the GNU Lesser General Public License	
 * along with UbuntuOne for Windows.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Authors: Manuel de la Peña <manuel.delapena@canonical.com>
 */
using System;
using System.Collections.Generic;

namespace Canonical.UbuntuOne.Common.Validation
{
    /// <summary>
    /// Represents a validation carried on the arguments of a method. 
    /// </summary>
    public sealed class ArgumentValidation
    {
        private readonly List<Exception> _exceptions;

        /// <summary>
        ///Creates a new argument validation result. 
        /// </summary>
        public ArgumentValidation()
        {
            _exceptions = new List<Exception>(1); // optimize for only having 1 exception
        }

        /// <value>
        /// Gets the exception of the result.
        /// </value>
        public IEnumerable<Exception> Exceptions
        {
            get
            {
                return _exceptions;
            }
        }

        /// <summary>
        /// Adds a new exception to the argument result. 
        /// </summary>
        /// <param name="ex">
        /// A <see cref="Exception"/> to be added to the validation result.
        /// </param>
        /// <returns>
        /// A <see cref="ArgumentValidation"/> with the result of the validation.
        /// </returns>
        public ArgumentValidation AddException(Exception ex)
        {
            lock (_exceptions)
            {
                _exceptions.Add(ex);
            }
            return this;
        }
    }
}