﻿/**
 * Copyright 2010 Canonical Ltd.
 * 
 * This file is part of UbuntuOne on Windows.
 * 
 * UbuntuOne on Windows is free software: you can redistribute it and/or modify		
 * it under the terms of the GNU Lesser General Public License version 		
 * as published by the Free Software Foundation.		
 *		
 * Ubuntu One on Windows is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
 * GNU Lesser General Public License for more details.	
 *
 * You should have received a copy of the GNU Lesser General Public License	
 * along with UbuntuOne for Windows.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Authors: Manuel de la Peña <manuel.delapena@canonical.com>
 */
using System;
using System.Runtime.Serialization;

namespace Canonical.UbuntuOne.Common.Validation
{
    /// <summary>
    ///Represents the basic exception used in the validation. 
    /// </summary>
    [Serializable]
    public class ValidationException : Exception
    {
        /// <summary>
        /// Creates a new exception. 
        /// </summary>
        public ValidationException()
        {
        }

        /// <summary>
        /// Creates a new exception with the given message. 
        /// </summary>
        /// <param name="message">
        /// A <see cref="System.String"/> with the message of the exception.
        /// </param>
        public ValidationException(string message)
            : base(message)
        {
        }

        /// <summary>
        ///  Creates a new exception with the given message and inner exception.
        /// </summary>
        /// <param name="message">
        /// A <see cref="System.String"/> with the message of the exception.
        /// </param>
        /// <param name="innerException">
        /// A <see cref="Exception"/> that represents the inner exception.
        /// </param>
        public ValidationException(string message, Exception innerException)
            : base(message, innerException)
        {
        }

        /// <summary>
        /// Creates a new exception from the serialization info.
        /// </summary>
        /// <param name="info">
        /// A <see cref="SerializationInfo"/> with the serialization info.
        /// </param>
        /// <param name="context">
        /// A <see cref="StreamingContext"/> with the serialization context.
        /// </param>
        protected ValidationException(SerializationInfo info, StreamingContext context)
            : base(info, context)
        {
        }
    }
}