﻿/**
 * Copyright 2010 Canonical Ltd.
 * 
 * This file is part of UbuntuOne on Windows.
 * 
 * UbuntuOne on Windows is free software: you can redistribute it and/or modify		
 * it under the terms of the GNU Lesser General Public License version 		
 * as published by the Free Software Foundation.		
 *		
 * Ubuntu One on Windows is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
 * GNU Lesser General Public License for more details.	
 *
 * You should have received a copy of the GNU Lesser General Public License	
 * along with UbuntuOne for Windows.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Authors: Manuel de la Peña <manuel.delapena@canonical.com>
 */
using Canonical.UbuntuOne.Common;
using NUnit.Framework;

namespace Canonical.UbuntuOne.ProcessDispatcher.Tests.Protobuf
{
    [TestFixture]
    public class SyncConfigurationMessageFactoryFixture
    {

        #region Setup

        private SyncConfigurationMessageFactory _factory;

        [SetUp]
        public void Setup()
        {
            _factory = new SyncConfigurationMessageFactory();
        }

        #endregion

        #region Tests

        [Test]
        public void QueryThrottlingTest()
        {
            var message = _factory.QueryThrottling();
            Assert.AreEqual(ConfigurationMessage.MessageType.QUERYTHROTTLING, message.Type);
        }

        [TestCase(4, 5)]
        [TestCase(5, 4)]
        public void SetThrottlingLimitsTest(int upload, int download)
        {
            var data = new ThrottlingData {Upload = upload, Download = download};
            var message = _factory.SetThrottlingLimits(data);
            Assert.AreEqual(ConfigurationMessage.MessageType.SETTHROTTLING, message.Type);
            Assert.AreEqual(upload, message.Throttling.Upload);
            Assert.AreEqual(download, message.Throttling.Download);
        }

        [TestCase(true)]
        [TestCase(false)]
        public void EnableThrottlingTest(bool isEnabled)
        {
            var message = _factory.EnableThrottling(isEnabled);
            Assert.AreEqual(ConfigurationMessage.MessageType.ENABLETHROTTLING, message.Type);
            Assert.AreEqual(isEnabled, message.ThrottlingEnabled);
        }

        [TestCase(true)]
        [TestCase(false)]
        public void EnablesAutosubscribeTest(bool isEnabled)
        {
            var message = _factory.EnablesAutosubscribe(isEnabled);
            Assert.AreEqual(ConfigurationMessage.MessageType.ENABLEAUTOSUBSCRIBE, message.Type);
            Assert.AreEqual(isEnabled, message.AutosubscribeEnabled);
        }

        #endregion

    }
}
