﻿/**
 * Copyright 2010 Canonical Ltd.
 * 
 * This file is part of UbuntuOne on Windows.
 * 
 * UbuntuOne on Windows is free software: you can redistribute it and/or modify		
 * it under the terms of the GNU Lesser General Public License version 		
 * as published by the Free Software Foundation.		
 *		
 * Ubuntu One on Windows is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
 * GNU Lesser General Public License for more details.	
 *
 * You should have received a copy of the GNU Lesser General Public License	
 * along with UbuntuOne for Windows.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Authors: Manuel de la Peña <manuel.delapena@canonical.com>
 */
using Canonical.UbuntuOne.Common.Validation;
using NUnit.Framework;

namespace Canonical.UbuntuOne.ProcessDispatcher.Tests.Protobuf
{
    [TestFixture]
    public class SyncFolderMessageFactoryFixture
    {

        #region Setup

        private SyncFolderMessageFactory _factory;

        [SetUp]
        public void Setup()
        {
            _factory = new SyncFolderMessageFactory();    
        }

        #endregion

        #region Tests

        [Test]
        [ExpectedException(typeof(ValidationException))]
        public void CreateFolderNullTest()
        {
            _factory.CreateFolder(null);   
        }

        [Test]
        [ExpectedException(typeof(ValidationException))]
        public void CreateFolderEmptyTest()
        {
            _factory.CreateFolder("");
        }

        [TestCase(@"/first/path")]
        [TestCase(@"/second/path")]
        public void CreateFolderTest(string path)
        {
            var message = _factory.CreateFolder(path);
            Assert.AreEqual(FolderMessage.MessageType.CREATEFOLDER, message.Type);
            Assert.AreEqual(path, message.Path);
        }

        [Test]
        [ExpectedException(typeof(ValidationException))]
        public void DeleteFolderNullTest()
        {
            _factory.DeleteFolder(null);   
        }

        [Test]
        [ExpectedException(typeof(ValidationException))]
        public void DeleteFolderEmptyTest()
        {
            _factory.DeleteFolder("");
        }

        [TestCase(@"/first/path")]
        [TestCase(@"/second/path")]
        public void DeleteFolderTest(string path)
        {
            var message = _factory.DeleteFolder(path);
            Assert.AreEqual(FolderMessage.MessageType.DELETEFOLDER, message.Type);
            Assert.AreEqual(path, message.Path);
        }

        [Test]
        public void QueryFoldersTest()
        {
            var message = _factory.QueryFolders();
            Assert.AreEqual(FolderMessage.MessageType.QUERYFOLDERS, message.Type);
        }

        [Test]
        [ExpectedException(typeof(ValidationException))]
        public void SubscribeNullTest()
        {
            _factory.Subscribe(null);   
        }

        [Test]
        [ExpectedException(typeof(ValidationException))]
        public void SubscribeEmptyTest()
        {
            _factory.Subscribe("");
        }

        [TestCase(@"/first/path")]
        [TestCase(@"/second/path")]
        public void SubscribeTest(string path)
        {
            var message = _factory.Subscribe(path);
            Assert.AreEqual(FolderMessage.MessageType.SUBSCRIBE, message.Type);
            Assert.AreEqual(path, message.Path);
        }

        [Test]
        public void RefreshFolders()
        {
            var message = _factory.RefreshFolders();
            Assert.AreEqual(FolderMessage.MessageType.REFRESH, message.Type);
        }

        [TestCase("firstPath")]
        [TestCase("secondPath")]
        public void QueryInfoTest(string path)
        {
            var message = _factory.QueryInfo(path);
            Assert.AreEqual(path, message.Path);
            Assert.AreEqual(FolderMessage.MessageType.QUERYINFO, message.Type);
        }

        [TestCase("firstId")]
        [TestCase("secondId")]
        public void UnsubscribeTest(string id)
        {
            var message = _factory.Unsubscribe(id);
            Assert.AreEqual(id, message.Path);
            Assert.AreEqual(FolderMessage.MessageType.UNSUBSCRIBE, message.Type);
        }

        #endregion

    }
}
