/**
 * Copyright 2010 Canonical Ltd.
 * 
 * This file is part of UbuntuOne on Windows.
 * 
 * UbuntuOne on Windows is free software: you can redistribute it and/or modify		
 * it under the terms of the GNU Lesser General Public License version 		
 * as published by the Free Software Foundation.		
 *		
 * Ubuntu One on Windows is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
 * GNU Lesser General Public License for more details.	
 *
 * You should have received a copy of the GNU Lesser General Public License	
 * along with UbuntuOne for Windows.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Authors: Manuel de la Peña <manuel.delapena@canonical.com>
 */
using Canonical.UbuntuOne.Common;
using Canonical.UbuntuOne.Common.Validation;
using NUnit.Framework;

namespace Canonical.UbuntuOne.ProcessDispatcher.Tests
{
    [TestFixture]
    public class SyncShareMessageFactoryFixture
    {
        #region Setup

        private SyncShareMessageFactory _factory;

        [SetUp]
        public void Setup()
        {
            _factory = new SyncShareMessageFactory();
        }


        #endregion

        #region Tests

        [Test]
        public void QuerySharesTest()
        {
            var message = _factory.QueryShares();
            Assert.AreEqual(ShareMessage.MessageType.QUERYOTHERSHARES, message.Type);
        }

        [Test]
        [ExpectedException(typeof(ValidationException))]
        public void AcceptShareNullTest()
        {
            _factory.AcceptShare(null);
        }

        [Test]
        [ExpectedException(typeof(ValidationException))]
        public void AcceptShareEmptyTest()
        {
            _factory.AcceptShare("");    
        }


        [TestCase(@"/first/path")]
        [TestCase(@"/second/path")]
        public void AcceptShareTest(string path)
        {
            var message = _factory.AcceptShare(path);
            Assert.AreEqual(ShareMessage.MessageType.ACCEPTSHARE, message.Type);
            Assert.AreEqual(path, message.ShareId);
        }

        [Test]
        [ExpectedException(typeof(ValidationException))]
        public void RejectShareNullTest()
        {
            _factory.RejectShare(null);
        }

        [Test]
        [ExpectedException(typeof(ValidationException))]
        public void RejectShareEmptyTest()
        {
            _factory.RejectShare("");
        }

        [TestCase(@"/first/path")]
        [TestCase(@"/second/path")]
        public void RejectShareTest(string path)
        {
            var message = _factory.RejectShare(path);
            Assert.AreEqual(ShareMessage.MessageType.REJECTSHARE, message.Type);
            Assert.AreEqual(path, message.ShareId);
        }

        [TestCase(null, "username", "name", AccessLevel.VIEW)]
        [TestCase("", "username", "name", AccessLevel.VIEW)]
        [TestCase("path", null, "name", AccessLevel.VIEW)]
        [TestCase("path", "", "name", AccessLevel.VIEW)]
        [TestCase("path", "username", null, AccessLevel.VIEW)]
        [TestCase("path", "username", "", AccessLevel.VIEW)]
        [ExpectedException(typeof(ValidationException))]
        public void CreatePathFailureTest(string path, string username, string name, AccessLevel level)
        {
            _factory.CreateShare(path, username, name, level);   
        }

        [TestCase("firstPath", "mandel", "myShare",  ShareMessage.AccessLevel.MODIFY)]
        [TestCase("secondPath", "beeita", "photos", ShareMessage.AccessLevel.VIEW)]
        public void CreateShare(string path, string username, string name, AccessLevel level)
        {
            var message = _factory.CreateShare(path, username, name, level);
            Assert.AreEqual(ShareMessage.MessageType.CREATESHARE, message.Type);
            Assert.AreEqual(path, message.Path);
            Assert.AreEqual(username, message.Username);
            Assert.AreEqual(name, message.Name);
        }

        [Test]
        public void UpdateSharesTest()
        {
            var message = _factory.UpdateShares();
            Assert.AreEqual(ShareMessage.MessageType.UPDATESHARES, message.Type);
        }

        [Test]
        public void GetSharedTest()
        {
            var message = _factory.GetShared();
            Assert.AreEqual(ShareMessage.MessageType.QUERYSHARED, message.Type);
        }
        #endregion
    }
}


