/**
 * Copyright 2010 Canonical Ltd.
 * 
 * This file is part of UbuntuOne on Windows.
 * 
 * UbuntuOne on Windows is free software: you can redistribute it and/or modify		
 * it under the terms of the GNU Lesser General Public License version 		
 * as published by the Free Software Foundation.		
 *		
 * Ubuntu One on Windows is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
 * GNU Lesser General Public License for more details.	
 *
 * You should have received a copy of the GNU Lesser General Public License	
 * along with UbuntuOne for Windows.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Authors: Manuel de la Pea <manuel.delapena@canonical.com>
 */
using Canonical.UbuntuOne.Common;

namespace Canonical.UbuntuOne.ProcessDispatcher
{
    /// <summary>
    /// Interface to be implemented by those factories that can creates a message to query data
    /// about the configuration of the daemon.
    /// </summary>
    internal interface ISyncConfigurationMessageFactory
    {
        /// <summary>
        /// Creates a new message that can be used to retrieve the trottling set up in the daemon.
        /// </summary>
        /// <returns>A message that can be used to retireve the throttling configuration of the 
        /// daemon.</returns>
        ConfigurationMessage QueryThrottling();

        /// <summary>
        /// Creates a new message that an be used to set the trottling used in the daemon.
        /// </summary>
        /// <param name="data">The new throttling to be used in the configuration.</param>
        /// <returns>A message that will allow to set the throttling.</returns>
        ConfigurationMessage SetThrottlingLimits(ThrottlingData data);

        /// <summary>
        /// Creates a new message that can be used to enable throttling in the daemon.
        /// </summary>
        /// <param name="isEnabled">A flag indicating if throttling is enabled.</param>
        /// <returns>A message that can be used to enable or disable throttling.</returns>
        ConfigurationMessage EnableThrottling(bool isEnabled);

        /// <summary>
        /// Creates a new message thatn can be used to enable that autosubscribe in the daemon.
        /// </summary>
        /// <param name="isEnabled">A flag indicating if the autosubscribe should be enabled.</param>
        /// <returns>A message that can be used to set the autosubscrive option of the daemon.</returns>
        ConfigurationMessage EnablesAutosubscribe(bool isEnabled);
    }
}