/**
 * Copyright 2010 Canonical Ltd.
 * 
 * This file is part of UbuntuOne on Windows.
 * 
 * UbuntuOne on Windows is free software: you can redistribute it and/or modify		
 * it under the terms of the GNU Lesser General Public License version 		
 * as published by the Free Software Foundation.		
 *		
 * Ubuntu One on Windows is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
 * GNU Lesser General Public License for more details.	
 *
 * You should have received a copy of the GNU Lesser General Public License	
 * along with UbuntuOne for Windows.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Authors: Manuel de la Pea <manuel.delapena@canonical.com>
 */
namespace Canonical.UbuntuOne.ProcessDispatcher
{
    /// <summary>
    /// Interface to be implemented by those factories that can create messages to query the daemon.
    /// </summary>
    internal interface ISyncDaemonMessageFactory
    {
        /// <summary>
        /// Creates a message that can be used to query the root of used by the sync daemon.
        /// </summary>
        /// <returns>A message that can be used to query the root of the daemon.</returns>
        SyncDaemonMessage QueryRoot();

        /// <summary>
        /// Creates a message that can be used to query the state of the sync daemon.
        /// </summary>
        /// <returns>A message that can be used to query the sync daemon about its state.</returns>
        SyncDaemonMessage QueryState();

        /// <summary>
        /// Creates a message that can be used to query the downloads that are currently in process 
        /// in the sycn daemon.
        /// </summary>
        /// <returns>A message that can be used to query the sync daemon about the current downloads.</returns>
        SyncDaemonMessage QueryDownloads();

        /// <summary>
        /// Creates a message that can be used to query the sync daemon about the items that are in the 
        /// queue to be processed.
        /// </summary>
        /// <returns>A message to query the queue of the daemon.</returns>
        SyncDaemonMessage QueryWaiting();

        /// <summary>
        /// Creates a message that can be used to query the sync daemon about the items that are currently
        /// being uploaded.
        /// </summary>
        /// <returns>A message that queries the current uploads in the daemon.</returns>
        SyncDaemonMessage QueryUploads();
    }
}