/**
 * Copyright 2010 Canonical Ltd.
 * 
 * This file is part of UbuntuOne on Windows.
 * 
 * UbuntuOne on Windows is free software: you can redistribute it and/or modify		
 * it under the terms of the GNU Lesser General Public License version 		
 * as published by the Free Software Foundation.		
 *		
 * Ubuntu One on Windows is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
 * GNU Lesser General Public License for more details.	
 *
 * You should have received a copy of the GNU Lesser General Public License	
 * along with UbuntuOne for Windows.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Authors: Manuel de la Pea <manuel.delapena@canonical.com>
 */
namespace Canonical.UbuntuOne.ProcessDispatcher
{
    internal interface ISyncFolderMessageFactory
    {
        /// <summary>
        /// Creates a new message that can be used to query the infor of a folder.
        /// </summary>
        /// <param name="folderId">The id of the folder whose info we are quering.</param>
        /// <returns>A message that can be sent to the daemon to query the information of a folder.</returns>
        FolderMessage QueryInfo(string folderId);

        /// <summary>
        /// Creates a message that can be used to create a new folder in the given path.
        /// </summary>
        /// <param name="path">The path where the folder is going to be created.</param>
        /// <returns>A message that can be sent to the daemon to create a folder.</returns>
        FolderMessage CreateFolder(string path);

        /// <summary>
        /// Creates a message that can be used to delete a folder in the givn path.
        /// </summary>
        /// <param name="path">The path to whcih the folder is going to be created.</param>
        /// <returns>A message that can be sent to the daemon to delete a folder.</returns>
        FolderMessage DeleteFolder(string path);

        /// <summary>
        /// Creates a message that can be used to query all the folder that the daemon knows about.
        /// </summary>
        /// <returns>A message that can be used to query all the folder in the daemon.</returns>
        FolderMessage QueryFolders();

        /// <summary>
        /// Creates a message that can be used to subscribe to a folder.
        /// </summary>
        /// <param name="folderId">The id that identifies the folder to whcih we want the daemon to subscribe.</param>
        /// <returns>A message that tells the daemon to subcribe to a folder.</returns>
        FolderMessage Subscribe(string folderId);

        /// <summary>
        /// Creates a message that can be used to unsbscribe the daemon from a folder.
        /// </summary>
        /// <param name="folderId">The id that identifies the folder to unsubscribe.</param>
        /// <returns>A message that tells the daemon to unsubscribe from a folder.</returns>
        FolderMessage Unsubscribe(string folderId);

        /// <summary>
        /// Creates a message that tells the daemon to refresh the folders.
        /// </summary>
        /// <returns>A message that tells the daemon to refresh the folders.</returns>
        FolderMessage RefreshFolders();
    }
}