/**
 * Copyright 2010 Canonical Ltd.
 * 
 * This file is part of UbuntuOne on Windows.
 * 
 * UbuntuOne on Windows is free software: you can redistribute it and/or modify		
 * it under the terms of the GNU Lesser General Public License version 		
 * as published by the Free Software Foundation.		
 *		
 * Ubuntu One on Windows is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
 * GNU Lesser General Public License for more details.	
 *
 * You should have received a copy of the GNU Lesser General Public License	
 * along with UbuntuOne for Windows.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Authors: Manuel de la Pea <manuel.delapena@canonical.com>
 */
using Canonical.UbuntuOne.Common;

namespace Canonical.UbuntuOne.ProcessDispatcher
{
    internal interface ISyncShareMessageFactory
    {
        /// <summary>
        /// Creates a new message that can be used wot wuery the shares in the sync daemon.
        /// </summary>
        /// <returns>A message that can be used to query the shares in the daemon.</returns>
        ShareMessage QueryShares();

        /// <summary>
        /// Creates a new message that will tell the sync daemon that a share has been accepted.
        /// </summary>
        /// <param name="shareId">The id of the share that has been accepted.</param>
        /// <returns>A message that can be used to tell that a share has been accepted.</returns>
        ShareMessage AcceptShare(string shareId);

        /// <summary>
        /// Creates a message that will tell the sync daemong to reject a share with the given share id.
        /// </summary>
        /// <param name="shareId">The id of the share to reject.</param>
        /// <returns>A message that lets the daemong know that we are rejecting a message.</returns>
        ShareMessage RejectShare(string shareId);

        /// <summary>
        /// Creates a new message that can be used to create a new share through the daemon.
        /// </summary>
        /// <param name="path">The path of the new share to create.</param>
        /// <param name="username">The username that will be able to access the share.</param>
        /// <param name="name">The name of the share.</param>
        /// <param name="accessLevel">The access level to be used in the share.</param>
        /// <returns>TA message that can be used to create a new share.</returns>
        ShareMessage CreateShare(string path, string username, string name, AccessLevel accessLevel);

        /// <summary>
        /// Creates a new message that will tell the sync daemon that has to update the shares.
        /// </summary>
        /// <returns>A message that can be used to tell the daemon to update the shares.</returns>
        ShareMessage UpdateShares();

        /// <summary>
        /// Creates a new message that query for the shares that the user has done.
        /// </summary>
        /// <returns>A message to query the daemon for the shares of the user.</returns>
        ShareMessage GetShared();
    }
}