﻿/**
 * Copyright 2010 Canonical Ltd.
 * 
 * This file is part of UbuntuOne on Windows.
 * 
 * UbuntuOne on Windows is free software: you can redistribute it and/or modify		
 * it under the terms of the GNU Lesser General Public License version 		
 * as published by the Free Software Foundation.		
 *		
 * Ubuntu One on Windows is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
 * GNU Lesser General Public License for more details.	
 *
 * You should have received a copy of the GNU Lesser General Public License	
 * along with UbuntuOne for Windows.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Authors: Manuel de la Peña <manuel.delapena@canonical.com>
 */
using Canonical.UbuntuOne.Common;
using Canonical.UbuntuOne.Common.Validation;

namespace Canonical.UbuntuOne.ProcessDispatcher
{
    /// <summary>
    /// Factory that can be used to create the messages to use when working with the share service.
    /// </summary>
    internal class SyncShareMessageFactory : ISyncShareMessageFactory
    {
        public ShareMessage QueryShares()
        {
            return new ShareMessage { Type = ShareMessage.MessageType.QUERYOTHERSHARES };
        }

        public ShareMessage AcceptShare(string shareId)
        {
            ValidateArgs.Begin()
                .IsNotNullOrEmpty(shareId, "shareId")
                .Check();

            return new ShareMessage
            {
                Type = ShareMessage.MessageType.ACCEPTSHARE, 
                ShareId = shareId
            };
        }

        public ShareMessage RejectShare(string shareId)
        {
            ValidateArgs.Begin()
                .IsNotNullOrEmpty(shareId, "shareId")
                .Check();

            return new ShareMessage
            {
                Type = ShareMessage.MessageType.REJECTSHARE, 
                ShareId = shareId
            };
        }

        public ShareMessage CreateShare(string path, string username, string name, AccessLevel accessLevel)
        {
            ValidateArgs.Begin()
                .IsNotNullOrEmpty(path, "path")
                .IsNotNullOrEmpty(username, "username")
                .IsNotNullOrEmpty(name, "name")
                .Check();

            var message = new ShareMessage
            {
                Type = ShareMessage.MessageType.CREATESHARE,
                Path = path,
                Username = username,
                Name = name
            };
            switch (accessLevel)
            {
                case AccessLevel.MODIFY:
                    message.Access = ShareMessage.AccessLevel.MODIFY;
                    break;
                default:
                    message.Access = ShareMessage.AccessLevel.VIEW;
                    break;
            }
            return message;
        }

        public ShareMessage UpdateShares()
        {
            return new ShareMessage {Type = ShareMessage.MessageType.UPDATESHARES};
        }

        public ShareMessage GetShared()
        {
            return new ShareMessage {Type = ShareMessage.MessageType.QUERYSHARED};
        }
    }
}
