﻿/**
 * Copyright 2010 Canonical Ltd.
 * 
 * This file is part of UbuntuOne on Windows.
 * 
 * UbuntuOne on Windows is free software: you can redistribute it and/or modify		
 * it under the terms of the GNU Lesser General Public License version 		
 * as published by the Free Software Foundation.		
 *		
 * Ubuntu One on Windows is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
 * GNU Lesser General Public License for more details.	
 *
 * You should have received a copy of the GNU Lesser General Public License	
 * along with UbuntuOne for Windows.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Authors: Manuel de la Peña <manuel.delapena@canonical.com>
 */
using System.ServiceModel;
using System.ServiceProcess;
using Canonical.UbuntuOne.Common.Update;
using log4net;

namespace Canonical.UbuntuOne.ProcessDispatcher
{
    /// <summary>
    /// This class represents the windows service that is able to launch the sync daemon accoring to the user.
    /// 
    /// This service is used to ensure that the sync daemon run sper user and allows to amange those processes.
    /// </summary>
    public class SyncDaemonWindowsService : ServiceBase
    {
        #region Variables

        public const string MyServiceName = "UbuntuOne SyncDaemon";
        private ServiceHost _host;
        private readonly object _loggerLock = new object();
        private ILog _logger;
        #endregion

        #region Properties

        public ILog Logger
        {
            get
            {
                if (_logger == null)
                {
                    lock (_loggerLock)
                    {
                        _logger = LogManager.GetLogger(typeof (SyncDaemonWindowsService));
                    }
                }
                return _logger;
            }
            set
            {
                _logger = value;
            }
        }

        /// <summary>
        /// DI interface that allows to inject an updater that will allow to update the application.
        /// </summary>
        public IUpdater Updater { get; set; }

        #endregion

        public SyncDaemonWindowsService()
        {
            InitializeComponent();
        }

        private void InitializeComponent()
        {
            this.ServiceName = MyServiceName;
        }

        /// <summary>
        /// Start this service.
        /// </summary>
        protected override void OnStart(string[] args)
        {
            if (_host != null)
            {
                Logger.WarnFormat("{0} was already running!", MyServiceName);
                _host.Close();
            }

            // Create a ServiceHost for the CalculatorService type and 
            // provide the base address.
            _host = new ServiceHost(typeof(SyncDaemonService));

            // Open the ServiceHostBase to create listeners and start 
            // listening for messages.
            // TODO: Open again when config is done
            //_host.Open();
            Logger.DebugFormat("{0} started.", MyServiceName);
        }

        /// <summary>
        /// Stop this service.
        /// </summary>
        protected override void OnStop()
        {
            if (_host == null) return;
            // TODO: Open again when config is done
            //_host.Close();
            _host = null;
            Logger.DebugFormat("{0} stopped", MyServiceName);
        }
    }
}
