#!/usr/bin/python
# Copyright 2010 Canonical Ltd.  All rights reserved.

"""This utilities release an Ubuntu One windows update."""

import sys
from zipfile import ZipFile
from xml.dom.minidom import parseString
import boto
from boto.s3.key import Key


MANIFEST_NAME = 'ubuntuone.manifest'
PACKAGES_BUCKET_PREFIX = 'vds'
MANIFEST_BUCKET = 'vds_manifest'

def upload_package(name, version, conn, package_filename):
    """Creates the bucket and upload the package"""
    new_bucket_name = '%s-%s-%s' % (PACKAGES_BUCKET_PREFIX, name, version)
    new_bucket_name = new_bucket_name.lower()
    bucket = conn.create_bucket(new_bucket_name)
    print 'New bucket created: %s' % new_bucket_name
    k = Key(bucket)
    k.key = package_filename
    k.set_contents_from_filename(package_filename)
    print 'Package uploaded: %s' % package_filename
    bucket.set_acl('public-read', package_filename)
    print 'Making package public: %s' % package_filename


def update_manifest(conn, manifest):
    bucket = conn.create_bucket((MANIFEST_BUCKET))
    k = Key(bucket)
    k.key = 'manifest'
    k.set_contents_from_string(manifest)
    print 'Manifest updated'
    bucket.set_acl('public-read', 'manifest')
    print 'Making manifest public'


def main(package_filename):
    """ """
    # prepare to upload
    packagezip = ZipFile(package_filename, 'r')
    manifest = packagezip.read(MANIFEST_NAME)
    manifest_dom = parseString(manifest)
    identity = manifest_dom.getElementsByTagName('assemblyIdentity')[0]
    name = identity.getAttribute('name')
    version = identity.getAttribute('version')
    # connect to S3
    print 'Connecting to S3...'
    conn = boto.connect_s3()
    print 'Connected!'
    upload_package(name, version, conn, package_filename)
    update_manifest(conn, manifest)


if __name__ == '__main__':
    argv = sys.argv
    #FIXME check we have AWS_ACCESS_KEY_ID and AWS_SECRET_ACCESS_KEY in the env
    if len (argv) != 2:
        print "Usage: upload_new_update.py package_file"
        sys.exit()
    sys.exit(main(package_filename=argv[1]))
